@@ -3,13 +3,20 @@ use std::path::PathBuf;
 
 fn main() {
     println!("cargo:rustc-link-lib=varnishapi");
-    println!("cargo:rerun-if-changed=src/wrapper.h");
+    let out_path = PathBuf::from(env::var("OUT_DIR").unwrap()).join("bindings.rs");
 
-    let vapi = pkg_config::Config::new()
+    let vapi = match pkg_config::Config::new()
         .atleast_version("7.0")
-        .probe("varnishapi")
-        .unwrap();
+        .probe("varnishapi") {
+            Ok(l) => l,
+            Err(e) => {
+                println!("no system libvarnish found, using the pre-generated bindings {}", e);
+                std::fs::copy("src/bindings.rs.saved", out_path).unwrap();
+                return;
+            }
+        };
 
+    println!("cargo:rerun-if-changed=src/wrapper.h");
     let bindings = bindgen::Builder::default()
         .header("src/wrapper.h")
         .blocklist_item("FP_.*")
@@ -23,8 +30,7 @@ fn main() {
         .expect("Unable to generate bindings");
 
     // Write the bindings to the $OUT_DIR/bindings.rs file.
-    let out_path = PathBuf::from(env::var("OUT_DIR").unwrap());
     bindings
-        .write_to_file(out_path.join("bindings.rs"))
+        .write_to_file(out_path)
         .expect("Couldn't write bindings!");
 }
